@@ -23,19 +23,13 @@
 
 #--------------------------------------------------------------------------------------
 """
-Launches a solver defined by the given solver ''case''. 
-Results of the solver work can be obtained by usage of ''[[cloudflu-solver-process]]'' 
-utility. These two utility was specially designed not just run together, 
-but do their work in parallel. The common entry point for both of these utilities 
-is ''study'', which could be reserver in advance by calling ''[[cloudflu-study-book]]'' 
-utility.
+This script is responsible for cluster environment setup for the given Amazon EC2 reservation
 """
 
 
 #--------------------------------------------------------------------------------------
 import cloudflu.common as common
-from cloudflu.common import print_d, print_e
-from cloudflu.common import Timer, sh_command
+from cloudflu.common import print_d, print_e, sh_command, Timer
 from cloudflu.common import ssh
 
 from cloudflu import amazon
@@ -76,8 +70,6 @@ def main() :
 
     common.concurrency_options.add( an_option_parser )
 
-    common.communication_options.add( an_option_parser )
-
     openmpi_config_options.add( an_option_parser )
 
     amazon.security_options.add( an_option_parser )
@@ -92,17 +84,15 @@ def main() :
     
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
     
-    a_cluster_id = ec2.use.options.extract( an_option_parser )
+    a_reservation_id = ec2.use.options.extract( an_option_parser )
 
     a_hostfile = openmpi_config_options.extract( an_option_parser )
 
-    a_socket_timeout = common.communication_options.extract( an_option_parser )
-
     a_number_threads = common.concurrency_options.extract( an_option_parser )
 
     an_upload_seed_size = data_seeding_options.extract( an_option_parser )
 
-    a_case_dir, a_run_hook, a_wait_run = solver_start_options.extract( an_option_parser )
+    a_case_dir, a_run_hook = solver_start_options.extract( an_option_parser )
 
     a_study_name = data_transfer_options.extract( an_option_parser )
     
@@ -111,18 +101,14 @@ def main() :
     a_host_port = int( get( 'amazon.cluster.host_port' ) )
     a_login_name = get( 'amazon.cluster.login_name' )
 
-    a_watched_keyword = get( 'amazon.timestamps_upload.watched_keyword' )
-    a_watching_timeout = get( 'amazon.timestamps_upload.watching_timeout' )
-    a_finish_hook = get( 'amazon.timestamps_upload.finish_hook' )
-
 
     print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
     import sys; an_engine = sys.argv[ 0 ]
 
     a_call = "%s %s %s %s %s" % ( an_engine,
-                                  ec2.use.options.compose( a_cluster_id ),
+                                  ec2.use.options.compose( a_reservation_id ),
                                   data_transfer_options.compose( a_study_name ), 
-                                  solver_start_options.compose( a_case_dir, a_run_hook, a_wait_run ),
+                                  solver_start_options.compose( a_case_dir, a_run_hook ),
                                   openmpi_config_options.compose( a_hostfile ) )
     print_d( a_call + '\n' )
 
@@ -131,7 +117,7 @@ def main() :
     a_spent_time = Timer()
 
     an_ec2_conn = ec2.common.region_connect( a_cluster_location, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY )
-    a_reservation = ec2.use.get_reservation( an_ec2_conn, a_cluster_id )
+    a_reservation = ec2.use.get_reservation( an_ec2_conn, a_reservation_id )
     print_d( '< %r > : %s\n' % ( a_reservation, a_reservation.instances ) )
 
     a_master_node = an_instance = a_reservation.instances[ 0 ]
@@ -145,7 +131,7 @@ def main() :
     print_d( "a_root_object = %s\n" % a_root_object )
     
     import data_upload
-    an_input_study = data_upload.entry_point( a_root_object, { a_case_dir : '' }, an_upload_seed_size, a_number_threads, a_socket_timeout )
+    an_input_study = data_upload.entry_point( a_root_object, { a_case_dir : '' }, an_upload_seed_size, a_number_threads )
 
     an_input_study_name = an_input_study.name()
     print_d( "an_input_study_name = '%s'\n" % an_input_study_name )
@@ -168,7 +154,7 @@ def main() :
     a_working_dir = a_stdout_lines[ 0 ][ : -1 ]
     print_d( "a_working_dir = '%s'\n" % a_working_dir )
 
-    ssh.command( a_ssh_client, "cloudflu-download --study-name=%s --output-dir=%s --remove" % ( an_input_study_name, a_working_dir ) )
+    ssh.command( a_ssh_client, "amazon_download.py --study-name=%s --output-dir=%s --remove" % ( an_input_study_name, a_working_dir ) )
     
     print_d( "\n--- Sharing the solver case folder for all the cluster nodes through NFS --\n" )
     ssh.command( a_ssh_client, "sudo sh -c 'echo %s *\(rw,no_root_squash,sync,subtree_check\) >> /etc/exports'" % ( a_working_dir ) )
@@ -195,38 +181,20 @@ def main() :
 
     a_target_dir = os.path.join( a_working_dir, a_case_name )
 
-    an_additional_args = "--booked"
-    an_additional_args += " --study-name='%s'" % ( a_study_name )
-    an_additional_args += " --upload-seed-size=%d" % ( an_upload_seed_size )
-    an_additional_args += " --watched-keyword='%s'" % ( a_watched_keyword )
-    if a_watching_timeout != None :
-        an_additional_args += " --watching-timeout=%d" % ( a_watching_timeout )
-        pass
-    an_additional_args += " --finish-hook='%s'" % ( a_finish_hook )
+    an_additional_args = "--study-name='%s' --booked --upload-seed-size=%d" % ( a_study_name, an_upload_seed_size )
 
-    a_command = "%s/%s %d '%s' %s" % ( a_target_dir, a_run_hook, a_num_nodes, a_hostfile, an_additional_args )
+    a_ssh_client = an_instance2ssh[ a_master_node ]
+    ssh.command( a_ssh_client, "%s/%s %d '%s' %s" % ( a_target_dir, a_run_hook, a_num_nodes, a_hostfile, an_additional_args ) )
 
-    if a_wait_run == False :
-        a_host_name = a_master_node.public_dns_name
-        a_ssh = ssh.options.command( a_password, an_identity_file, a_host_port, a_login_name, a_host_name )
-        import os.path; a_log_file = os.path.join( a_working_dir, 'log.%s' % a_run_hook )
-        a_ssh += ' -n -f "source /etc/profile && nohup %s > %s 2>&1 &"' % ( a_command, a_log_file )
-        print_d( '%s\n' % a_ssh )
+    an_output_study.seal()
 
-        import os; os.system( a_ssh )
-    else:
-        a_ssh_client = an_instance2ssh[ a_master_node ]
-
-        ssh.command( a_ssh_client, a_command )
-        pass
-    
     [ a_ssh_client.close() for a_ssh_client in an_instance2ssh.values() ]
-
+    
     print_d( "a_spent_time = %s, sec\n" % a_spent_time )
     
 
     print_d( "\n------------------ Printing succussive pipeline arguments -----------------\n" )
-    ec2.use.options.track( a_cluster_id )
+    ec2.use.options.track( a_reservation_id )
 
     
     print_d( "\n--------------------------- Canonical substitution ------------------------\n" )
