@@ -29,18 +29,18 @@ import os, os.path
 
 #--------------------------------------------------------------------------------------
 def usage_description() :
-    return " --cluster-id='r-8cc1dfe7'"
+    return " --reservation-id='r-8cc1dfe7'"
 
 
 #--------------------------------------------------------------------------------------
 from cloudflu.preferences import OptionGroup, PersistentOption, TransientOption
 a_container = OptionGroup( 'amazon.ec2.use' )
 
-a_container.add_option( TransientOption( "--cluster-id",
-                                          metavar = "< cluster identifier >",
+a_container.add_option( TransientOption( "--reservation-id",
+                                          metavar = "< Amazon EC2 Reservation ID >",
                                           action = "store",
-                                          dest = "cluster_id",
-                                          help = "(read from standard input, if not specified)",
+                                          dest = "reservation_id",
+                                          help = "(read from standard input, if not given)",
                                           default = None ) )
 
 
@@ -48,29 +48,29 @@ a_container.add_option( TransientOption( "--cluster-id",
 def extract( the_option_parser ) :
     an_options, an_args = the_option_parser.parse_args()
 
-    a_cluster_id = an_options.cluster_id
-    if a_cluster_id == None :
+    a_reservation_id = an_options.reservation_id
+    if a_reservation_id == None :
         from cloudflu.preferences import get_input
-        a_cluster_id, an_args = get_input( an_args )
+        a_reservation_id, an_args = get_input( an_args )
         pass
     
-    if a_cluster_id == None :
-        the_option_parser.error( "--cluster-id is not defined\n" )
+    if a_reservation_id == None :
+        the_option_parser.error( "--reservation-id is not defined\n" )
         pass
 
-    print_d( "a_cluster_id = '%s'\n" % a_cluster_id )
+    print_d( "a_reservation_id = '%s'\n" % a_reservation_id )
 
-    return a_cluster_id
+    return a_reservation_id
 
 
 #--------------------------------------------------------------------------------------
-def compose( the_cluster_id ) :
-    return "--cluster-id='%s'" % ( the_cluster_id )
+def compose( the_reservation_id ) :
+    return "--reservation-id='%s'" % ( the_reservation_id )
 
 
 #--------------------------------------------------------------------------------------
-def track( the_cluster_id ) :
-    print the_cluster_id    
+def track( the_reservation_id ) :
+    print the_reservation_id    
     pass
 
 
